Revelation Indicator
====================

This small application is a re-write of the revelation-applet to work in
Ubuntu's new `Unity <http://unity.ubuntu.com>`_ desktop. It implements an
indicator application that allows easy read-only access to your revelation
account database.

Installation
============

To install the indicator just run::

    $ sudo python setup.py install

After that you can start it by running::

    $ revelation-indicator

If you want ``revelation-indicator`` to load at startup just add new launcher
in the *Startup Application* dialog.

Contribute
==========

Contributing is easy: give me some feedback, file a bug fix or feature request.
And if you want to do even more: fork it, do your magic and send me a pull
request :)

License
=======

This piece of software is licensed under the GPL v3. For more information on 
this, and how to apply and follow the GNU GPL, see http://www.gnu.org/licenses.
